@@ -1328,8 +1328,9 @@ class Members extends AdminController
 				'action_update' => (isset($element->update) ? (int) $element->update : 1),
 				'action_edit'   => (isset($element->edit)   ? (int) $element->edit   : 1),
 				'action_browse' => (isset($element->browse) ? (int) $element->browse : 0),
-				'min'           => (isset($element->min) ? (int) $element->min : 0),
-				'max'           => (isset($element->max) ? (int) $element->max : 0)
+				'min'           => (isset($element->field_options->min) ? (int) $element->field_options->min : 0),
+				'max'           => (isset($element->field_options->max) ? (int) $element->field_options->max : 0),
+				'default_value' => (isset($element->field_options->value) ? (string) $element->field_options->value : '')
 			));
 
 			if ($field->get('type') == 'dropdown')
